##  Self-Referencing Relations
Self-referencing relations enable you to create relations between fact sheets of the same type. These relations work like regular relations between fact sheets, with the exception that both ends of the relation target the same fact sheet type.
When you create a self-referencing relation, two subsections are generated on a fact sheet to represent both ends of the relation. Like with regular relations, you can create fields on self-referencing relations.
With self-referencing relations, you can create relations between subtypes of the same fact sheet type, for example, between business applications and microservices, which are subtypes of the application fact sheet. After you’ve created a self-referencing relation, make the relation conditional by using conditional attributes. This allows you to ensure that only the relevant relation appears on a specific fact sheet subtype. For more information, see [Creating a Conditional Relation Between Subtypes of the Same Fact Sheet Type](https://help.sap.com/docs/leanix/ea/fact-sheet-relations?locale=en-US&state=PRODUCTION&version=CLOUD#loio275a0dc97a441014a475ddbf4c6de047__creating_a_conditional_relation_between_subtypes_of_the_same_fact_sheet_type).
